package com.zd.laboratory.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

import com.zd.common.core.domain.per.PerFun;
import com.zd.common.core.domain.per.PerPrefix;
import com.zd.common.core.web.domain.ResultData;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zd.common.log.annotation.Log;
import com.zd.common.log.enums.BusinessType;
import com.zd.common.security.annotation.PreAuthorize;
import com.zd.laboratory.domain.LabViolationRecord;
import com.zd.laboratory.service.ILabViolationRecordService;
import com.zd.common.core.web.controller.BaseController;
import com.zd.common.core.web.domain.AjaxResult;
import com.zd.common.core.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.zd.common.swagger.config.Knife4jConfiguration;

import com.zd.common.core.web.page.TableDataInfo;

/**
 * 违规记录Controller
 *
 * @author zd
 * @date 2021-12-14
 */
@RestController
@Api(tags = "【违规记录】")
//作者手动加入 ，在接口上加作者@ApiOperationSupport(author = "XXX")
@RequestMapping("/violationRecord")
public class LabViolationRecordController extends BaseController
{
    @Autowired
    private ILabViolationRecordService labViolationRecordService;

    /**
     * 查询违规记录列表
     */
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_VIOLATIONRECORD + PerFun.LIST)
    @GetMapping("/list")
    @ApiOperation(value = "查询违规记录列表")
    public TableDataInfo<LabViolationRecord> list(LabViolationRecord labViolationRecord)
    {
        startPage();
        List<LabViolationRecord> list = labViolationRecordService.selectLabViolationRecordList(labViolationRecord);
        return getDataTable(list);
    }

    /**
     * 导出违规记录列表
     */
    @ApiOperation(value = "导出违规记录列表")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_VIOLATIONRECORD + PerFun.EXPORT)
    @Log(title = "违规记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, LabViolationRecord labViolationRecord) throws IOException
    {
        List<LabViolationRecord> list = labViolationRecordService.selectLabViolationRecordList(labViolationRecord);
        ExcelUtil<LabViolationRecord> util = new ExcelUtil<LabViolationRecord>(LabViolationRecord.class);
        util.exportExcel(response, list, "违规记录数据");
    }

    /**
     * 获取违规记录详细信息
     */
    @ApiOperation(value = "获取违规记录详细信息")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_VIOLATIONRECORD + PerFun.QUERY)
    @GetMapping(value = "/{id}")
    public ResultData<LabViolationRecord> getInfo(@PathVariable("id") Long id)
    {
        return ResultData.success(labViolationRecordService.selectLabViolationRecordById(id));
    }

    /**
     * 新增违规记录
     */
    @ApiOperation(value = "新增违规记录")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_VIOLATIONRECORD + PerFun.ADD)
    @Log(title = "违规记录", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultData add(@RequestBody LabViolationRecord labViolationRecord)
    {
        return ResultData.result(labViolationRecordService.insertLabViolationRecord(labViolationRecord));
    }

    /**
     * 修改违规记录
     */
    @ApiOperation(value = "修改违规记录")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_VIOLATIONRECORD + PerFun.EDIT)
    @Log(title = "违规记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultData edit(@RequestBody LabViolationRecord labViolationRecord)
    {
        return  ResultData.result(labViolationRecordService.updateLabViolationRecord(labViolationRecord));
    }

    /**
     * 删除违规记录
     */
    @ApiOperation(value = "删除违规记录")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_VIOLATIONRECORD + PerFun.REMOVE)
    @Log(title = "违规记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public ResultData remove(@PathVariable Long[] ids)
    {
        return ResultData.result(labViolationRecordService.deleteLabViolationRecordByIds(ids));
    }
}
